@@ -175,7 +175,7 @@ logview_update_toolbar (LogviewWindow *logview,
   }
 
   if (gtk_widget_get_visible (logview->priv->find_bar)) {
-    text = g_strdup_printf ("Search in \"%s\"",
+    text = g_strdup_printf (_("Search in \"%s\""),
                             logview_log_get_display_name (active));
     gd_main_toolbar_set_labels (GD_MAIN_TOOLBAR (logview->priv->toolbar),
                                 text, NULL);
@@ -351,7 +351,7 @@ wrap:
   if (!active_log)
     return;
 
-  primary = g_strdup_printf ("Search in \"%s\"",
+  primary = g_strdup_printf (_("Search in \"%s\""),
                              logview_log_get_display_name (active_log));
   gd_main_toolbar_set_labels (GD_MAIN_TOOLBAR (logview->priv->toolbar), primary, secondary);
 
